C Soft photon integration of its Phase Space for a energy cut of omega
C Based on De'93, Fortschr. Phys. 41, (1993) 307-420
C This file is part of aITALC
C Copyright (C) 2004 Alejandro Lorca <alejandro.lorca@desy.de>
C-----------------------------------------------------------------------
      double precision function INTEGRATEDPHOTON(i,j,FRAC,photonmass2)
      implicit none
      
      double precision frac,photonmass2
      integer i,j

      double precision qi0,modqi,qi2,plusi,minusi
      double precision qj0,modqj,qj2,plusj,minusj
      double precision plusai,minusai,myroot,v,be,dli2,ddilog
      double precision a,x,z,condition,expandterm
#include <variablelist.hf>
C-----------------------------------------------------------------------

      call MOMENTUM(j,qj0,modqj,plusj,minusj,qj2)
      if (i.eq.j) then
C Eq. 7.20
        INTEGRATEDPHOTON=2*pi*( 
     &       +DLOG(4*frac**2*sman/photonmass2) 
     &       +(qj0/modqj)*DLOG(minusj/plusj)
     &       )
        go to 100
      endif
      call MOMENTUM(i,qi0,modqi,plusi,minusi,qi2)
C Case of massless particles, only possible for fermion=neutrinos, no charged
      if ((qj2.eq.0d0).or.(qi2.eq.0d0)) then
        INTEGRATEDPHOTON=0d0
        go to 100
      endif
C Computing a:= alpha in paper, z is just qiqj/qi2 with Mandelstam variable.
      z=(MANDARRAY(i,j)-qi2-qj2)/(2*qi2)
      myroot=DSQRT(z**2-qj2/qi2)
        if (DABS(1+myroot/z).lt.1D-6) then
          expandterm=qj2/(qi2*z**2)
c          print *,'Taylor approx order 2 made'
          a=z*(expandterm/2+(expandterm**2)/8)
        else
          a=z+myroot
        endif
C Since a can be positive or negative: we choose it to keep eq 7.19
      condition=(a*qi0-qj0)/qj0
      if (condition.lt.0d0) then
C Only to avoid lose of precision
        if (DABS(1-myroot/z).lt.1D-6) then
c          print *,'Taylor approx order 2 made'
          a=z*(expandterm/2+(expandterm**2)/8)
        else
          a=z-myroot
        endif
        condition=(a*qi0-qj0)/qj0
      endif
      if (condition.lt.0d0) then
        print *,'integratedphothon: nothing works with the sign! check'
        stop
      endif

      plusai= a*plusi
      minusai=a*minusi
C Eq. 7.18      
      v=(a**2*qi2-qj2)/(2*(a*qi0-qj0))
C Eq. 7.17      
      INTEGRATEDPHOTON=
     &     +DLOG(a**2*qi2/qj2)*DLOG(4*frac**2*sman/photonmass2)/2
     &     +(DLOG(minusai/plusai)**2-DLOG(minusj/plusj)**2)/4
     &     +(DDILOG(1- plusai/v)-DDILOG(1-plusj/v))
     &     +(DDILOG(1-minusai/v)-DDILOG(1-minusj/v))

c      print 11,'a=',a
c      print 11,'v=',v
c      print 11,'plui',plusi
c      print 11,'mini',minusi      
c      print 11,'logs',+(DLOG(minusai/plusai)**2-DLOG(minusj/plusj)**2)/4
c      print 11,'di+a',DDILOG(1-plusai/v)
c      print 11,'di-a',DDILOG(1-minusai/v)
c      print 11,'pluj',plusj
c      print 11,'minj',minusj
c      print 11,'di+',-DDILOG(1-plusj/v)
c      print 11,'di-',-DDILOG(1-minusj/v)
c      print 11,'PROD',2*pi*a*(MANDARRAY(i,j)-qi2-qj2)/(a**2*qi2-qj2)

      INTEGRATEDPHOTON=INTEGRATEDPHOTON
     &     *2*pi*a*(MANDARRAY(i,j)-qi2-qj2)/(a**2*qi2-qj2) 

 11   format (A5,E22.16)

c      print 10,'PSI(',i,j,')=',INTEGRATEDPHOTON
 10   format (A5,I2,I2,A3,E22.16)


 100  return
      end
CC $Id: integratedphoton.F,v 1.3 2004/10/07 15:05:12 alorca Exp $
